@@ -67,6 +67,7 @@ class BwtApi:
         _logger.debug(f"Fetching current data from {self._host}")
         raw = await self.__get_data("GetCurrentData")
         errors = [BwtError(int(error)) for error in raw["ActiveErrorIDs"].split(",") if error]
+        perla_one = raw["CapacityColumn2_ml_dH"] == -1
         
         in_hardness = Hardness(
             raw["HardnessIN_CaCO3"],
@@ -106,6 +107,7 @@ class BwtApi:
             raw["WaterTreatedCurrentDay_l"],
             raw["WaterTreatedCurrentMonth_l"],
             raw["WaterTreatedCurrentYear_l"],
+            1 if perla_one else 2,
         )
 
     async def get_daily_data(self) -> DailyResponse:
@@ -132,3 +134,9 @@ class BwtApi:
         raw = await self.__get_data("GetYearlyData")
         keys = [f"Month{month:02}_l" for month in range(1, 13)]
         return YearlyResponse(list(map(lambda k: raw[k], keys)))
+
+def treated_to_blended(treated: int, hardness_in: int, hardness_out: int) -> float:
+    if (hardness_in == 0 | hardness_in == hardness_out):
+        return treated
+
+    return treated / (1.0 - hardness_out / hardness_in)
\ No newline at end of file
