@@ -2,7 +2,7 @@ from datetime import datetime
 from zoneinfo import ZoneInfo
 import pytest
 
-from bwt_api.api import BwtApi
+from bwt_api.api import BwtApi, treated_to_blended
 from bwt_api.error import BwtError
 from bwt_api.data import CurrentResponse, Hardness, BwtStatus
 
@@ -89,6 +89,43 @@ current_json_empty_errors = """
 }
 """
 
+current_json_perla_one = """
+{
+   "ActiveErrorIDs" : "",
+   "BlendedWaterSinceSetup_l" : 189985,
+   "CapacityColumn1_ml_dH" : 4487511,
+   "CapacityColumn2_ml_dH" : -1,
+   "CurrentFlowrate_l_h" : 0,
+   "DosingSinceSetup_ml" : 0,
+   "FirmwareVersion" : "2.0211",
+   "HardnessIN_CaCO3" : 409,
+   "HardnessIN_dH" : 23,
+   "HardnessIN_fH" : 41,
+   "HardnessIN_mmol_l" : 4,
+   "HardnessOUT_CaCO3" : 107,
+   "HardnessOUT_dH" : 6,
+   "HardnessOUT_fH" : 11,
+   "HardnessOUT_mmol_l" : 1,
+   "HolidayModeStartTime" : 0,
+   "LastRegenerationColumn1" : "2025-01-15 03:00:15",
+   "LastRegenerationColumn2" : "1970-01-01 00:59:59",
+   "LastServiceCustomer" : "2024-11-25 09:13:48",
+   "LastServiceTechnican" : "2023-08-07 11:13:51",
+   "OutOfService" : 0,
+   "RegenerationCountSinceSetup" : 692,
+   "RegenerationCounterColumn1" : 692,
+   "RegenerationCounterColumn2" : 0,
+   "RegenerativLevel" : 37,
+   "RegenerativRemainingDays" : 62,
+   "RegenerativSinceSetup_g" : 207305,
+   "ShowError" : 0,
+   "WaterSinceSetup_l" : 148544,
+   "WaterTreatedCurrentDay_l" : 179,
+   "WaterTreatedCurrentMonth_l" : 514,
+   "WaterTreatedCurrentYear_l" : 500
+}
+"""
+
 async def test_wrong_code():
     with aioresponses() as mocked:
         mocked.get("http://host:8080/api/GetCurrentData", status=404, body="")
@@ -146,6 +183,7 @@ async def test_current_data():
                 treated_day=181,
                 treated_month=3137,
                 treated_year=80700,
+                columns=2,
             )
 
 
@@ -180,4 +218,47 @@ async def test_empty_errors():
                 treated_day=181,
                 treated_month=3137,
                 treated_year=80700,
+                columns=2,
             )
+
+
+async def test_perla_one():
+    with aioresponses() as mocked:
+        mocked.get("http://host:8080/api/GetCurrentData", status=200, body=current_json_perla_one)
+        async with BwtApi("host", "code") as api:
+            result = await api.get_current_data()
+            assert result == CurrentResponse(
+                errors=[],
+                blended_total=189985,
+                capacity_1=4487511,
+                capacity_2=-1,
+                current_flow=0,
+                dosing_total=0,
+                firmware_version="2.0211",
+                in_hardness=Hardness(caco3=409, dH=23, fH=41, mmol=4),
+                out_hardness=Hardness(caco3=107, dH=6, fH=11, mmol=1),
+                holiday_mode=0,
+                regeneration_last_1=datetime(2025, 1, 15, 3, 0, 15, 0, ZoneInfo("UTC")),
+                regeneration_last_2=datetime(1970, 1, 1, 0, 59, 59, 0, ZoneInfo("UTC")),
+                service_customer=datetime(2024, 11, 25, 9, 13, 48, 0, ZoneInfo("UTC")),
+                service_technician=datetime(2023, 8, 7, 11, 13, 51, 0, ZoneInfo("UTC")),
+                out_of_service=0,
+                regeneration_count_1=692,
+                regeneration_count_2=0,
+                regeneration_count=692,
+                regenerativ_level=37,
+                regenerativ_days=62,
+                regenerativ_total=207305,
+                state=BwtStatus.OK,
+                treated_day=179,
+                treated_month=514,
+                treated_year=500,
+                columns=1,
+            )
+
+def test_treated_to_blended():
+    assert treated_to_blended(0, 21, 4) == 0
+    assert treated_to_blended(100, 21, 21) == 100
+    assert treated_to_blended(10, 20, 4) == 12.5
+    assert treated_to_blended(306, 21, 4) == 378
+    assert treated_to_blended(191, 21, 4) == pytest.approx(235.9411)
